import * as React from 'react';
import { getIntrinsicElementProps, mergeCallbacks, slot } from '@fluentui/react-components';
import { $getNodeByKey, useLexicalComposerContext } from '@fluentui-copilot/react-text-editor';
// If you add JSX to this file, be sure to change the file type to .tsx
/**
 * Create the state required to render GhostText.
 *
 * The returned state can be modified with hooks such as useGhostTextStyles_unstable,
 * before being passed to renderGhostText_unstable.
 *
 * @param props - props from this instance of GhostText
 * @param ref - reference to root HTMLElement of GhostText
 */
export const useGhostText_unstable = (props, ref) => {
  const {
    nodeKey,
    onClick,
    ...rest
  } = props;
  const [editor] = useLexicalComposerContext();
  const handleClick = React.useCallback(_ev => {
    if (!nodeKey) {
      return;
    }
    editor.update(() => {
      var _node_getPreviousSibling;
      const node = $getNodeByKey(nodeKey);
      node === null || node === void 0 ? void 0 : (_node_getPreviousSibling = node.getPreviousSibling()) === null || _node_getPreviousSibling === void 0 ? void 0 : _node_getPreviousSibling.selectEnd();
    }, {
      tag: 'historic'
    });
  }, [editor, nodeKey]);
  const mergedOnClick = mergeCallbacks(handleClick, onClick);
  const state = {
    components: {
      root: 'span',
      indicator: 'span'
    },
    root: slot.always(getIntrinsicElementProps('span', {
      ref,
      onClick: mergedOnClick,
      ...rest
    }), {
      elementType: 'span'
    }),
    indicator: slot.optional(props.indicator, {
      elementType: 'span'
    })
  };
  return state;
};
//# sourceMappingURL=useGhostText.js.map