import * as React from 'react';
import { useLexicalComposerContext } from '@fluentui-copilot/react-text-editor';
import { useIsomorphicLayoutEffect } from '@fluentui/react-components';
import { BasicFunctionalityBase } from '@fluentui-copilot/chat-input-plugins';
export const BasicFunctionalityPlugin = React.forwardRef((props, ref) => {
  const {
    defaultValue,
    trimWhitespace,
    onCountChanged,
    onContentChange,
    onPaste,
    isSentinelNodeEnabled
  } = props;
  const [editor] = useLexicalComposerContext();
  const [basicFunctionalityImpl, setBasicFunctionalityImpl] = React.useState(null);
  useIsomorphicLayoutEffect(() => {
    setBasicFunctionalityImpl(new BasicFunctionalityBase(editor, isSentinelNodeEnabled));
    return () => {
      setBasicFunctionalityImpl(prev => {
        prev === null || prev === void 0 ? void 0 : prev.cleanup();
        return null;
      });
    };
  }, [editor, isSentinelNodeEnabled]);
  React.useImperativeHandle(ref, () => ({
    setIsDisabled(isDisabled) {
      basicFunctionalityImpl === null || basicFunctionalityImpl === void 0 ? void 0 : basicFunctionalityImpl.setIsDisabled(isDisabled);
    }
  }), [basicFunctionalityImpl]);
  const setDefaultValue = React.useRef(false);
  // useIsomorphicLayoutEffect is used to avoid flickering on first render
  useIsomorphicLayoutEffect(() => {
    if (basicFunctionalityImpl && !setDefaultValue.current) {
      if (defaultValue) {
        basicFunctionalityImpl.insertDefaultValue(defaultValue);
      }
      setDefaultValue.current = true;
    }
  }, [basicFunctionalityImpl, defaultValue, editor]);
  React.useEffect(() => {
    basicFunctionalityImpl === null || basicFunctionalityImpl === void 0 ? void 0 : basicFunctionalityImpl.activateContentCallbacks(onContentChange, onCountChanged);
    return () => basicFunctionalityImpl === null || basicFunctionalityImpl === void 0 ? void 0 : basicFunctionalityImpl.deactivateContentCallbacks();
  }, [basicFunctionalityImpl, editor, onContentChange, onCountChanged]);
  React.useEffect(() => {
    if (onPaste) {
      basicFunctionalityImpl === null || basicFunctionalityImpl === void 0 ? void 0 : basicFunctionalityImpl.activatePasteCallback(onPaste);
    }
    return () => basicFunctionalityImpl === null || basicFunctionalityImpl === void 0 ? void 0 : basicFunctionalityImpl.deactivatePasteCallback();
  }, [basicFunctionalityImpl, editor, onPaste]);
  React.useEffect(() => {
    if (trimWhitespace) {
      basicFunctionalityImpl === null || basicFunctionalityImpl === void 0 ? void 0 : basicFunctionalityImpl.activateTrimWhitespace();
    }
    return () => basicFunctionalityImpl === null || basicFunctionalityImpl === void 0 ? void 0 : basicFunctionalityImpl.deactivateTrimWhitespace();
  }, [basicFunctionalityImpl, editor, trimWhitespace]);
  return null;
});
//# sourceMappingURL=BasicFunctionality.js.map